@@ -1,6 +1,6 @@
 package DBIx::Class::Schema::AuditLog::Structure::Action;
 {
-  $DBIx::Class::Schema::AuditLog::Structure::Action::VERSION = '0.3.1';
+  $DBIx::Class::Schema::AuditLog::Structure::Action::VERSION = '0.4.0';
 }
 
 use base 'DBIx::Class::Schema::AuditLog::Structure::Base';
@@ -25,7 +25,7 @@ __PACKAGE__->add_columns(
         'is_nullable' => 0,
     },
     'audited_row' => {
-        'data_type'   => 'integer',
+        'data_type'   => 'tinytext',
         'is_nullable' => 0,
     },
     'type' => {
@@ -58,6 +58,7 @@ __PACKAGE__->has_many(
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -66,11 +67,11 @@ DBIx::Class::Schema::AuditLog::Structure::Action
 
 =head1 VERSION
 
-version 0.3.1
+version 0.4.0
 
 =head1 AUTHOR
 
-Mark Jubenville <ioncache@gmail.com>
+Mark Jubenville <ioncache@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -80,4 +81,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
