@@ -1,6 +1,6 @@
 package DBIx::Class::Schema::AuditLog::Structure::Base;
 {
-  $DBIx::Class::Schema::AuditLog::Structure::Base::VERSION = '0.3.1';
+  $DBIx::Class::Schema::AuditLog::Structure::Base::VERSION = '0.4.0';
 }
 
 use base 'DBIx::Class::Core';
@@ -8,6 +8,7 @@ use base 'DBIx::Class::Core';
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -16,11 +17,11 @@ DBIx::Class::Schema::AuditLog::Structure::Base
 
 =head1 VERSION
 
-version 0.3.1
+version 0.4.0
 
 =head1 AUTHOR
 
-Mark Jubenville <ioncache@gmail.com>
+Mark Jubenville <ioncache@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -30,4 +31,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
