@@ -1,6 +1,6 @@
 package DBIx::Class::Schema::AuditLog::Structure::Changeset;
 {
-  $DBIx::Class::Schema::AuditLog::Structure::Changeset::VERSION = '0.3.1';
+  $DBIx::Class::Schema::AuditLog::Structure::Changeset::VERSION = '0.4.0';
 }
 
 use base 'DBIx::Class::Schema::AuditLog::Structure::Base';
@@ -51,6 +51,7 @@ __PACKAGE__->has_many(
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -59,11 +60,11 @@ DBIx::Class::Schema::AuditLog::Structure::Changeset
 
 =head1 VERSION
 
-version 0.3.1
+version 0.4.0
 
 =head1 AUTHOR
 
-Mark Jubenville <ioncache@gmail.com>
+Mark Jubenville <ioncache@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -73,4 +74,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
