@@ -1,6 +1,6 @@
 package DBIx::Class::Schema::AuditLog::Structure::User;
 {
-  $DBIx::Class::Schema::AuditLog::Structure::User::VERSION = '0.3.1';
+  $DBIx::Class::Schema::AuditLog::Structure::User::VERSION = '0.4.0';
 }
 
 use base 'DBIx::Class::Schema::AuditLog::Structure::Base';
@@ -36,6 +36,7 @@ __PACKAGE__->has_many(
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -44,11 +45,11 @@ DBIx::Class::Schema::AuditLog::Structure::User
 
 =head1 VERSION
 
-version 0.3.1
+version 0.4.0
 
 =head1 AUTHOR
 
-Mark Jubenville <ioncache@gmail.com>
+Mark Jubenville <ioncache@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -58,4 +59,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
